@@ -46,7 +46,14 @@ sub _build_json {
 
 sub serialize {
     my ( $self, @args ) = @_;
-    $self->encode( $self->collapse_jspon(@args) );
+    my $json = eval { $self->encode( $self->collapse_jspon(@args) ) };
+    if ( $@ ) {
+        use Data::Dumper;
+        warn Dumper($self->collapse_jspon(@args), @args);
+        die $@;
+    }
+
+    return $json;
 }
 
 sub deserialize {
@@ -92,7 +99,7 @@ with L<KiokuDB::Backend::Serialize::JSPON> semantics
 
 =head1 SYNOPSIS
 
-	with qw(KiokuDB::Backend::Serialize::JSON);
+    with qw(KiokuDB::Backend::Serialize::JSON);
 
     sub foo {
         my ( $self, $entry ) = @_;
@@ -106,6 +113,8 @@ This role provides additional convenience attributes and methods for backends
 that encode entries to JSON strings, on top of
 L<KiokuDB::Backend::Serialize::JSPON> which only restructures the data.
 
+L<KiokuDB::Backend::Serialize::Delegate> is preferred to using this directly.
+
 =head1 METHODS
 
 =over 4
